==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningCategoryStyleEventArgsBaseDescriptionMetadata } from "./AssigningCategoryStyleEventArgsBaseDescriptionMetadata";
import { AssigningCategoryMarkerStyleEventArgsDescription } from "./AssigningCategoryMarkerStyleEventArgsDescription";
/**
 * @hidden
 */
export let AssigningCategoryMarkerStyleEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class AssigningCategoryMarkerStyleEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.a == null) {
                AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.c(AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.a);
            }
            if (a.j(AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            AssigningCategoryStyleEventArgsBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.b(a);
            a.aa("AssigningCategoryMarkerStyleEventArgs", () => new AssigningCategoryMarkerStyleEventArgsDescription());
            a.z("AssigningCategoryMarkerStyleEventArgs", AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.a);
        }
    }
    AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(AssigningCategoryMarkerStyleEventArgsDescriptionMetadata, 'AssigningCategoryMarkerStyleEventArgsDescriptionMetadata');
    AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.a = null;
    return AssigningCategoryMarkerStyleEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningCategoryStyleEventArgsBaseDescriptionMetadata } from "./AssigningCategoryStyleEventArgsBaseDescriptionMetadata";
import { AssigningCategoryMarkerStyleEventArgsDescription } from "./AssigningCategoryMarkerStyleEventArgsDescription";
/**
 * @hidden
 */
export let AssigningCategoryMarkerStyleEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class AssigningCategoryMarkerStyleEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.a == null) {
                AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.c(AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.a);
            }
            if (a.k(AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            AssigningCategoryStyleEventArgsBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.b(a);
            a.ac("AssigningCategoryMarkerStyleEventArgs", () => new AssigningCategoryMarkerStyleEventArgsDescription());
            a.ab("AssigningCategoryMarkerStyleEventArgs", AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.a);
        }
    }
    AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(AssigningCategoryMarkerStyleEventArgsDescriptionMetadata, 'AssigningCategoryMarkerStyleEventArgsDescriptionMetadata');
    AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.a = null;
    return AssigningCategoryMarkerStyleEventArgsDescriptionMetadata;
})();
